pub enum Kind {
Constant = 0,
Plain = 1,
Fsst = 2,
Dict = 3,
}Expand description
What a string chunk is encoded as. The discriminant is the tag byte and is part of the format.
Variants
Constant = 0
One value repeated.
Plain = 1
Lengths and raw bytes.
Fsst = 2
Lengths, a symbol table, and FSST compressed bytes.
Dict = 3
The distinct values as a string chunk of their own, and codes into it as an integer chunk.
Implementations