decode

Function decode 

pub fn decode(bytes: &[u8]) -> Result<Vec<i64>>
Decodes a chunk written by encode.

Errors

If the bytes are truncated, carry an unknown tag, or describe a chunk whose parts do not agree with each other.