tally

Function tally 

pub fn tally(bytes: &[u8]) -> Result<(usize, Vec<(i64, u64)>)>
Counts values in one encoded chunk without expanding sparse or run-length chunks into rows.

The result is computed from the encoded row values when called. It is not a stored histogram. Other encodings use the ordinary decoder until they have a useful count form of their own.

Errors

As decode, or if a sparse position or run length is outside the chunk.